# raster-indices-calc
Module created to allow for quick raster index calculation from Landsat-8 using gdal and numpy.   
Pulls .TIF files directly from Landsat-8 database with unedited file names. If file names have been changed simply edit each function to pull proper bands.


Indices
- NDVI
- SAVI 
- NDMI
- MNDWI
- AWEIsh
